pub struct ShaderBuffer {
pub data: Option<Vec<u8>>,
pub buffer_description: BufferDescriptor<Option<&'static str>>,
pub asset_usage: RenderAssetUsages,
pub copy_on_resize: bool,
}Expand description
A storage buffer that is prepared as a RenderAsset and uploaded to the GPU.
Fields
data: Option<Vec<u8>>Optional data used to initialize the buffer.
buffer_description: BufferDescriptor<Option<&'static str>>The buffer description used to create the buffer.
asset_usage: RenderAssetUsagesThe asset usage of the storage buffer.
copy_on_resize: boolWhether this buffer should be copied on the GPU when resized.
Implementations
Sourceimpl ShaderBuffer
impl ShaderBuffer
Sourcepub fn new(data: &[u8], asset_usage: RenderAssetUsages) -> ShaderBuffer
pub fn new(data: &[u8], asset_usage: RenderAssetUsages) -> ShaderBuffer
Creates a new storage buffer with the given data and asset usage.
Sourcepub fn with_size(size: usize, asset_usage: RenderAssetUsages) -> ShaderBuffer
pub fn with_size(size: usize, asset_usage: RenderAssetUsages) -> ShaderBuffer
Creates a new storage buffer with the given size and asset usage.
Sourcepub fn set_data<T>(&mut self, value: T)where
T: ShaderType + WriteInto,
pub fn set_data<T>(&mut self, value: T)where
T: ShaderType + WriteInto,
Sets the data of the storage buffer to the given ShaderType.
Sourcepub fn resize(&mut self, size: u64)
pub fn resize(&mut self, size: u64)
Resizes the buffer to the new size.
If CPU data is present, it will be truncated or zero-extended. Does not preserve GPU data when the descriptor changes.
Sourcepub fn resize_in_place(&mut self, size: u64)
pub fn resize_in_place(&mut self, size: u64)
Resizes the buffer to the new size, preserving existing data.
If CPU data is present, it will be truncated or zero-extended.
If no CPU data is present, sets copy_on_resize to preserve GPU data.